/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef WINUSER_H
#define WINUSER_H

#include "Screen/Point.hpp"

enum {
  DT_LEFT = 0x2,
  DT_NOCLIP = 0x4,
  DT_WORDBREAK = 0x8,
  DT_CENTER = 0x20,
  DT_NOPREFIX = 0,
  DT_VCENTER = 0x80,
  DT_RIGHT = 0x100,
  DT_CALCRECT = 0x400,
  DT_UNDERLINE = 0x800,
};

#endif
